/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include <tizen.h>
#include <app.h>
#include <dlog.h>
#include <Evas.h>
#include <Ecore.h>
#include <glib.h>
#include <stdlib.h>
#include <Elementary.h>
#include <system_settings.h>
#include <efl_extension.h>
#include <locations.h>
#include <maps_service.h>

#if !defined(_DATA_H)
#define _DATA_H

#define REQ_ID_IDLE				-1
#define NUM_OF_CATEGORY			5
#define MAX_PLACES				100
#define MAX_RESULT_OF_SEARCH	25
#define MAX_ROUTE_PATH			500
#define RADIUS_OF_SEARCH		5000	/* meters */

typedef enum {
	EMPTY_VIEW = 0,
	MAIN_VIEW,
	SEARCH_VIEW,
	SEARCH_RESULT_VIEW,
	ROUTE_VIEW,
} view_type;

typedef struct {
	double latitude;
	double longitude;
} location_info_s;

typedef struct {
	location_info_s location;
	double distance;
	char place_name[PATH_MAX];
	maps_view_object_h marker;
} place_info_s;

typedef struct {
	double distance;
	int duration;

	location_info_s path[MAX_ROUTE_PATH];
	int path_count;
} route_info_s;

typedef struct appdata {
	Evas_Object *win;
	Evas_Object *nf;
	Elm_Object_Item *nf_it;
	Evas_Object *ctxpopup;
	Evas_Object *toolbar;
	Evas_Object *hoversel;

	view_type prev_view;

	Evas_Object *map_image_layout;

	Evas_Object *main_view_layout;
	Evas_Object *main_map_layout;
	Evas_Object *main_entry;
	Evas_Object *main_address_btn;

	Evas_Object *search_view_layout;
	Evas_Object *search_entry;
	Evas_Object *search_genlist;

	Evas_Object *search_result_layout;

	Evas_Object *route_view_layout;
	Evas_Object *route_from_entry;
	Evas_Object *route_to_entry;
	Evas_Object *route_info_btn;

	bool is_search_route_supported;
	bool is_search_place_supported;
	bool is_reverse_geocode_supported;

	place_info_s *tmp_place;

	route_info_s *route;
	place_info_s *start_place;
	place_info_s *destination;

	int total_poi;
	place_info_s *poi_places[MAX_PLACES];

	maps_service_h maps_service_handle;
	maps_view_h map_view_handle;
} appdata_s;

/*
 * Initialize the data component.
 */
void data_initialize(appdata_s *ad);

/*
 * Finalize the data component.
 */
void data_finalize(void);

#endif
